@@ -87,7 +87,6 @@ class TestGenerators(LazygalTestGen):
         with open(os.path.join(dest_path, 'subgal', 'index.json')) as json_fp:
             pindex = json.load(json_fp)
             self.assertEqual(pindex['medias'], {'subgal_img.jpg': {
-                'comment': None,
                 'date': '2010-02-05T23:56:24',
                 'width': 640,
                 'height': 427,
@@ -450,7 +449,7 @@ class TestGenerators(LazygalTestGen):
         # Check that metadata is not in the JSON index
         with open(os.path.join(dest_dir, 'index.json')) as json_fp:
             pindex = json.load(json_fp)
-            self.assertFalse('metadata' in pindex['medias']['md_filled.jpg'])
+            self.assertFalse(pindex['medias']['md_filled.jpg']['metadata'])
 
     def test_resize_rotate_size(self):
         config = lazygal.config.LazygalConfig()
@@ -500,6 +499,16 @@ class TestGenerators(LazygalTestGen):
         dest_path = self.get_working_path()
         self.album.generate(dest_path)
 
+    def test_webalbumpic_bg(self):
+        config = lazygal.config.LazygalConfig()
+        config.set('webgal', 'webalbumpic-bg', 'black')
+        self.setup_album(config)
+
+        self.add_img(self.source_dir, 'img.jpg')
+
+        dest_path = self.get_working_path()
+        self.album.generate(dest_path)
+
     def test_feed(self):
         config = lazygal.config.LazygalConfig()
         config.set('global', 'puburl', 'http://example.com/album/')
